@@ -316,7 +316,7 @@ class CreatorDesignWindow(tk.Toplevel):
         img = ImageGrab.grab(bbox=bbox)
 
         # image name
-        filename = f'docs/images/ttkcreator.png'
+        filename = f'../docs/images/ttkcreator.png'
         print(filename)
         img.save(filename, 'png')
 
